# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/notification.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n opus_protobuf/notification.proto\x12\x0cnotification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto2Q\n\x16NotificationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOTIFICATIONCONTROLLER']._serialized_start=107
  _globals['_NOTIFICATIONCONTROLLER']._serialized_end=188
# @@protoc_insertion_point(module_scope)
