# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/user.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18opus_protobuf/user.proto\x12\x04user\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"\xde\x01\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x12\n\x05\x65mail\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x04type\x18\x05 \x01(\x0b\x32\x0e.user.UserType\x12.\n\x0fprofile_picture\x18\x06 \x01(\x0b\x32\x10.common.DocumentH\x01\x88\x01\x01\x12\x15\n\x08verified\x18\x07 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_emailB\x12\n\x10_profile_pictureB\x0b\n\t_verified\"&\n\x08UserType\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\"S\n\x1e\x43reateTalentOpportunityRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06talent\x18\x02 \x01(\t\x12\x13\n\x0bopportunity\x18\x03 \x01(\t\"i\n\x1f\x43reateTalentOpportunityResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0f\n\x07\x63ompany\x18\x02 \x01(\t\x12\x0e\n\x06talent\x18\x03 \x01(\t\x12\x13\n\x0bopportunity\x18\x04 \x01(\t\"#\n\x13GetShortLinkRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t2\xa1\x04\n\x0eUserController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12/\n\x07GetUser\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x12h\n\x17\x43reateTalentOpportunity\x12$.user.CreateTalentOpportunityRequest\x1a%.user.CreateTalentOpportunityResponse\"\x00\x12\x39\n\x11UploadCompanyLogo\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12\x42\n\x1aUploadCulturalAlertPicture\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12?\n\x17UploadCulturalAlertDeck\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12<\n\x14UploadVideoTreatment\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12=\n\x0cGetShortLink\x12\x19.user.GetShortLinkRequest\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USER']._serialized_start=92
  _globals['_USER']._serialized_end=314
  _globals['_USERTYPE']._serialized_start=316
  _globals['_USERTYPE']._serialized_end=354
  _globals['_CREATETALENTOPPORTUNITYREQUEST']._serialized_start=356
  _globals['_CREATETALENTOPPORTUNITYREQUEST']._serialized_end=439
  _globals['_CREATETALENTOPPORTUNITYRESPONSE']._serialized_start=441
  _globals['_CREATETALENTOPPORTUNITYRESPONSE']._serialized_end=546
  _globals['_GETSHORTLINKREQUEST']._serialized_start=548
  _globals['_GETSHORTLINKREQUEST']._serialized_end=583
  _globals['_USERCONTROLLER']._serialized_start=586
  _globals['_USERCONTROLLER']._serialized_end=1131
# @@protoc_insertion_point(module_scope)
