# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import authentication_pb2 as opus__protobuf_dot_authentication__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2


class AuthenticationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/authentication.AuthenticationController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.Login = channel.unary_unary(
                '/authentication.AuthenticationController/Login',
                request_serializer=opus__protobuf_dot_authentication__pb2.LoginRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.Signup = channel.unary_unary(
                '/authentication.AuthenticationController/Signup',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.GetUserData = channel.unary_unary(
                '/authentication.AuthenticationController/GetUserData',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.User.FromString,
                )
        self.SignupGoogle = channel.unary_unary(
                '/authentication.AuthenticationController/SignupGoogle',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.SignupApple = channel.unary_unary(
                '/authentication.AuthenticationController/SignupApple',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupAppleRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.UploadProfilePicture = channel.unary_unary(
                '/authentication.AuthenticationController/UploadProfilePicture',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadProfilePictureUrl = channel.unary_unary(
                '/authentication.AuthenticationController/UploadProfilePictureUrl',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.TalentProfileCreateCSV = channel.unary_unary(
                '/authentication.AuthenticationController/TalentProfileCreateCSV',
                request_serializer=opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                )
        self.RefreshToken = channel.unary_unary(
                '/authentication.AuthenticationController/RefreshToken',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )


class AuthenticationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Signup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignupGoogle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignupApple(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadProfilePicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadProfilePictureUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TalentProfileCreateCSV(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthenticationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.LoginRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'Signup': grpc.unary_unary_rpc_method_handler(
                    servicer.Signup,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'GetUserData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserData,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.User.SerializeToString,
            ),
            'SignupGoogle': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupGoogle,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'SignupApple': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupApple,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupAppleRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'UploadProfilePicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadProfilePicture,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadProfilePictureUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadProfilePictureUrl,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'TalentProfileCreateCSV': grpc.unary_unary_rpc_method_handler(
                    servicer.TalentProfileCreateCSV,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'authentication.AuthenticationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthenticationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/Login',
            opus__protobuf_dot_authentication__pb2.LoginRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Signup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/Signup',
            opus__protobuf_dot_authentication__pb2.SignupRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/GetUserData',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignupGoogle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/SignupGoogle',
            opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignupApple(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/SignupApple',
            opus__protobuf_dot_authentication__pb2.SignupAppleRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadProfilePicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/UploadProfilePicture',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadProfilePictureUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/UploadProfilePictureUrl',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TalentProfileCreateCSV(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/TalentProfileCreateCSV',
            opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Document.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/RefreshToken',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
