# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/score.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19opus_protobuf/score.proto\x12\x08\x61nalyzer\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"$\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x61pproved\x18\x02 \x01(\x08\"&\n\x05Posts\x12\x1d\n\x05posts\x18\x01 \x03(\x0b\x32\x0e.analyzer.Post\"@\n\nUserReport\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x15\n\rsocialNetwork\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\t\"n\n\nPostReport\x12\x14\n\x0creport_likes\x18\x01 \x01(\x05\x12\x16\n\x0ereport_comment\x18\x02 \x01(\x05\x12\x18\n\x10positive_comment\x18\x03 \x01(\x05\x12\x18\n\x10negative_comment\x18\x04 \x01(\x05\" \n\rResponseRight\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x1e\n\nIndustries\x12\x10\n\x08industry\x18\x01 \x03(\t2\xcd\x03\n\x0fScoreController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12>\n\x0c\x43reateTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12>\n\x0cUpdateTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12>\n\x0c\x44\x65leteTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12\x42\n\x10\x43reateSocialCard\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12@\n\x0e\x43reateAudience\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12;\n\x0f\x43reateAuthority\x12\x14.analyzer.Industries\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.score_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POST']._serialized_start=96
  _globals['_POST']._serialized_end=132
  _globals['_POSTS']._serialized_start=134
  _globals['_POSTS']._serialized_end=172
  _globals['_USERREPORT']._serialized_start=174
  _globals['_USERREPORT']._serialized_end=238
  _globals['_POSTREPORT']._serialized_start=240
  _globals['_POSTREPORT']._serialized_end=350
  _globals['_RESPONSERIGHT']._serialized_start=352
  _globals['_RESPONSERIGHT']._serialized_end=384
  _globals['_INDUSTRIES']._serialized_start=386
  _globals['_INDUSTRIES']._serialized_end=416
  _globals['_SCORECONTROLLER']._serialized_start=419
  _globals['_SCORECONTROLLER']._serialized_end=880
# @@protoc_insertion_point(module_scope)
