# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import score_pb2 as opus__protobuf_dot_score__pb2


class ScoreControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/analyzer.ScoreController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.CreateTalent = channel.unary_unary(
                '/analyzer.ScoreController/CreateTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.UpdateTalent = channel.unary_unary(
                '/analyzer.ScoreController/UpdateTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.DeleteTalent = channel.unary_unary(
                '/analyzer.ScoreController/DeleteTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateSocialCard = channel.unary_unary(
                '/analyzer.ScoreController/CreateSocialCard',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateAudience = channel.unary_unary(
                '/analyzer.ScoreController/CreateAudience',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateAuthority = channel.unary_unary(
                '/analyzer.ScoreController/CreateAuthority',
                request_serializer=opus__protobuf_dot_score__pb2.Industries.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class ScoreControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSocialCard(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAudience(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAuthority(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ScoreControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'CreateTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'UpdateTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'DeleteTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateSocialCard': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSocialCard,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateAudience': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAudience,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateAuthority': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAuthority,
                    request_deserializer=opus__protobuf_dot_score__pb2.Industries.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'analyzer.ScoreController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ScoreController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/UpdateTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/DeleteTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSocialCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateSocialCard',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAudience(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateAudience',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAuthority(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateAuthority',
            opus__protobuf_dot_score__pb2.Industries.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
