# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/authentication.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"opus_protobuf/authentication.proto\x12\x0e\x61uthentication\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18opus_protobuf/user.proto\x1a\x1aopus_protobuf/common.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"W\n\rSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"m\n\x0bJWTResponse\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0b\x32\x0e.user.UserType\x12\x0f\n\x07tenants\x18\x03 \x03(\t\x12\x15\n\x08verified\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x0b\n\t_verified\"2\n\x13SignupGoogleRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"1\n\x12SignupAppleRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8d\x01\n\x1dTalentProfileCreateCsvRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08\x62irthday\x18\x02 \x01(\t\x12\x0e\n\x06tenant\x18\x03 \x03(\t\x12\x10\n\x08industry\x18\x04 \x01(\t\x12\x18\n\x10industry_segment\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t2\xdf\x05\n\x18\x41uthenticationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12\x44\n\x05Login\x12\x1c.authentication.LoginRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x46\n\x06Signup\x12\x1d.authentication.SignupRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x33\n\x0bGetUserData\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x12R\n\x0cSignupGoogle\x12#.authentication.SignupGoogleRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12P\n\x0bSignupApple\x12\".authentication.SignupAppleRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12<\n\x14UploadProfilePicture\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12?\n\x17UploadProfilePictureUrl\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12[\n\x16TalentProfileCreateCSV\x12-.authentication.TalentProfileCreateCsvRequest\x1a\x10.common.Document\"\x00\x12\x45\n\x0cRefreshToken\x12\x16.google.protobuf.Empty\x1a\x1b.authentication.JWTResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=137
  _globals['_LOGINREQUEST']._serialized_end=184
  _globals['_SIGNUPREQUEST']._serialized_start=186
  _globals['_SIGNUPREQUEST']._serialized_end=273
  _globals['_JWTRESPONSE']._serialized_start=275
  _globals['_JWTRESPONSE']._serialized_end=384
  _globals['_SIGNUPGOOGLEREQUEST']._serialized_start=386
  _globals['_SIGNUPGOOGLEREQUEST']._serialized_end=436
  _globals['_SIGNUPAPPLEREQUEST']._serialized_start=438
  _globals['_SIGNUPAPPLEREQUEST']._serialized_end=487
  _globals['_TALENTPROFILECREATECSVREQUEST']._serialized_start=490
  _globals['_TALENTPROFILECREATECSVREQUEST']._serialized_end=631
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_start=634
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_end=1369
# @@protoc_insertion_point(module_scope)
