# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aopus_protobuf/common.proto\x12\x06\x63ommon\"?\n\x08\x44ocument\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x03_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04X_id\"\x19\n\x0bGetItemByID\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x06Health\x12\x0e\n\x06health\x18\x01 \x01(\x08\"\x17\n\x08Response\x12\x0b\n\x03res\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DOCUMENT']._serialized_start=38
  _globals['_DOCUMENT']._serialized_end=101
  _globals['_GETITEMBYID']._serialized_start=103
  _globals['_GETITEMBYID']._serialized_end=128
  _globals['_HEALTH']._serialized_start=130
  _globals['_HEALTH']._serialized_end=154
  _globals['_RESPONSE']._serialized_start=156
  _globals['_RESPONSE']._serialized_end=179
# @@protoc_insertion_point(module_scope)
