# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2


class UserControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/user.UserController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/user.UserController/GetUser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.User.FromString,
                )
        self.CreateTalentOpportunity = channel.unary_unary(
                '/user.UserController/CreateTalentOpportunity',
                request_serializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.FromString,
                )
        self.UploadCompanyLogo = channel.unary_unary(
                '/user.UserController/UploadCompanyLogo',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCulturalAlertPicture = channel.unary_unary(
                '/user.UserController/UploadCulturalAlertPicture',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCulturalAlertDeck = channel.unary_unary(
                '/user.UserController/UploadCulturalAlertDeck',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadVideoTreatment = channel.unary_unary(
                '/user.UserController/UploadVideoTreatment',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetShortLink = channel.unary_unary(
                '/user.UserController/GetShortLink',
                request_serializer=opus__protobuf_dot_user__pb2.GetShortLinkRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class UserControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTalentOpportunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCompanyLogo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCulturalAlertPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCulturalAlertDeck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadVideoTreatment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetShortLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.User.SerializeToString,
            ),
            'CreateTalentOpportunity': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTalentOpportunity,
                    request_deserializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.SerializeToString,
            ),
            'UploadCompanyLogo': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCompanyLogo,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCulturalAlertPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCulturalAlertPicture,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCulturalAlertDeck': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCulturalAlertDeck,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadVideoTreatment': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadVideoTreatment,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetShortLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetShortLink,
                    request_deserializer=opus__protobuf_dot_user__pb2.GetShortLinkRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'user.UserController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/GetUser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTalentOpportunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/CreateTalentOpportunity',
            opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.SerializeToString,
            opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCompanyLogo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCompanyLogo',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCulturalAlertPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCulturalAlertPicture',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCulturalAlertDeck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCulturalAlertDeck',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadVideoTreatment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadVideoTreatment',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetShortLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/GetShortLink',
            opus__protobuf_dot_user__pb2.GetShortLinkRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
